package uk.ac.shef.is.imageClef.cluster;

import java.io.File;
import java.text.DecimalFormat;
import java.text.NumberFormat;
import java.util.HashMap;

import uk.ac.shef.is.imageClef.clusterAssessment.ClusterAssessmentParser;
import uk.ac.shef.is.imageClef.clusterAssessment.ClusterAssessmentsContainer;
import uk.ac.shef.is.imageClef.clusterAssessment.ClusterTopicAssessmentsContainer;
import uk.ac.shef.is.imageClef.qrel.QrelParser;
import uk.ac.shef.is.imageClef.qrel.QrelsContainer;
import uk.ac.shef.is.imageClef.trecResult.TrecResultParser;
import uk.ac.shef.is.imageClef.trecResult.TrecResultsContainer;

/** Class is responsible to get the cluster recall (and precision
 * at certain points). This class is the counterpart of trecEval
 * to calculate the results how diverse the result is.
 * @author thomas
 *
 */
public class ClusterEval {
	//TODO interpolated recall
	private static int[] recallPositions = {5,10,15,20,30,50,100,1000};
	 
	/** Start the process evaluation the cluster recall
	 * @param pathToParticipantsResultFile Path to participants result file (TREC-style)
	 * @param pathToQrelFile Path to Qrel File
	 * @param pathToClusterAssessmentFile Phat to cluster assessment file
	 * @return Cluster Eval output
	 */
	public static String eval(String pathToParticipantsResultFile, String pathToQrelFile, String pathToClusterAssessmentFile){
		TrecResultsContainer trc = TrecResultParser.parse(new File(pathToParticipantsResultFile));
		QrelsContainer qrelsContainer = QrelParser.parseQrelFile(new File(pathToQrelFile)); //reads qrel-file
		ClusterAssessmentsContainer cap = ClusterAssessmentParser.parse(new File(pathToClusterAssessmentFile)); //reads cluster assessment file
		return clusterRecall(trc, qrelsContainer,cap);
	}
	
	/** Start the process evaluation the cluster recall
	 * @param trc TrecResultsContainer
	 * @param qrelsContainer QrelsContainer
	 * @param cap ClusterAssessmentsContainer
	 * @return Cluster Eval output
	 */
	public static String eval(TrecResultsContainer trc, QrelsContainer qrelsContainer, ClusterAssessmentsContainer cap){
		return clusterRecall(trc, qrelsContainer,cap);
	}
	
	private static String clusterRecall(TrecResultsContainer trc, QrelsContainer qrelsContainer, ClusterAssessmentsContainer cap){
		HashMap<String, ClusterTopicAssessmentsContainer> clusterAssessmentContainer = cap.getTopicClusterAssessments();
		StringBuffer sb = new StringBuffer();
		NumberFormat formatter = new DecimalFormat("0.0000");
		String[] topics = trc.getTopicNumbers();
		for (String topicNr : topics) { // analyse all given topics in the trec result
			for(int j =0; j < recallPositions.length; j++){
				if(qrelsContainer.isValidTopicNr(topicNr)){
					double clusterRecall = ClusterRecall.getClusterRecall(topicNr, recallPositions[j], trc, qrelsContainer, clusterAssessmentContainer);
					sb.append("CR@" + recallPositions[j] + "\t" +topicNr + "\t" + formatter.format(clusterRecall) + System.getProperty("line.separator"));
				}
				else{
					System.err.println("No valid topicNr : " + topicNr + " in file " + trc.getFilePath());
					break;
				}
			}
		}
		// get averages over all topics
		for(int j =0; j < recallPositions.length; j++){ 
			double avergageClusterRecall = ClusterRecall.getAverageClusterRecall(recallPositions[j], trc, qrelsContainer,clusterAssessmentContainer );
			sb.append("CR@" + recallPositions[j] + "\tall\t" + formatter.format(avergageClusterRecall) + System.getProperty("line.separator"));
		}
		return sb.toString();
	}
}
