package uk.ac.shef.is.imageClef.qrel;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.StringTokenizer;

public class QrelParser {
	private static QrelsContainer qrels;
	
	/** Parse a QREL file and return a QrelsContainer with the relevance assessments
	 * @param qrelFile QREL file
	 * @return QrelsContainer which contains the relevance assessments (relevants only)
	 */
	public static QrelsContainer parseQrelFile(File qrelFile){
		qrels = new QrelsContainer();
		try {
			BufferedReader input = new BufferedReader(new InputStreamReader(new FileInputStream(qrelFile)));
			try {
				String line = null; //not declared within while loop
				while ((line = input.readLine()) != null) {
					parseQrelFileLine(line);					
				}
			} finally {
				input.close();
			}
		} catch (IOException ex) {
			ex.printStackTrace();
		}
		return qrels;
	}
	
	/** Method parse a line from a qrel-file to determine
	 * the topic-number, doc-number and the relevance.
	 * Only if the document is considered relevant to the 
	 * given topic further process is applied.
	 * @param line
	 */
	private static void parseQrelFileLine(String line){
		line = line.trim();
		StringTokenizer tokenizer = new StringTokenizer (line, " ,\t");
		String topicNr = tokenizer.nextToken();
		tokenizer.nextToken();
		String docNr = tokenizer.nextToken();
		String rel = tokenizer.nextToken();	
		if(rel.equals("1")){ // take only relevant documents
			TopicQrelsContainer tq = qrels.getTopicQrels(topicNr);
			tq.addJudgement(docNr, "1");
		}
	}	
}