package uk.ac.shef.is.imageClef.qrel;

import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

/** Class is container of a whole QREL file
 * @author Thomas Arni
 *
 */
public class QrelsContainer{
	//qrels <topicNr, TopicQrelsContainer<docNr, relevance>>
	private HashMap<String, TopicQrelsContainer> qrels = new HashMap<String, TopicQrelsContainer>();
	
	/** Return the TopicQrelsContainer to a given topic
	 * @param topicNr Requested topic
	 * @return TopicQrelsContainer
	 */
	public TopicQrelsContainer getTopicQrels(String topicNr){
		if(qrels.containsKey(topicNr)){
			return qrels.get(topicNr);
		}
		else{
			TopicQrelsContainer ttr = new TopicQrelsContainer(topicNr);
			qrels.put(topicNr, ttr);
			return ttr;
		}
	}		
	
	/** Returns true if a given document is relevant in the topic 
	 * @param topicNr topic number
	 * @param docNr document number
	 * @return True if doc is relevant
	 */
	public boolean isRelevant(String topicNr, String docNr){
		if(qrels.containsKey(topicNr)){
			return qrels.get(topicNr).isRelevant(docNr);
		}
		return false;
	}
	
	/** Return true if the provided topic number occur in the Qrel-file. 
	 * It assumes that every topic has at least on relevant images.
	 * @param topicNr topic number
	 * @return true if valid topic number
	 */
	public boolean isValidTopicNr(String topicNr) {
		if(qrels.containsKey(topicNr)){
			return true;
		}
		else return false;
	}
	
	/**
	 * Print Qrel file
	 */
	public void printQrels(){
		Iterator<Map.Entry<String, TopicQrelsContainer>> it = qrels.entrySet().iterator();
		while(it.hasNext()){
			Map.Entry<String, TopicQrelsContainer> entry = (Map.Entry<String, TopicQrelsContainer>)it.next();
			TopicQrelsContainer tq = entry.getValue();
			HashMap<String, String> topicResults = tq.getTopicQrels();
			Iterator<Map.Entry<String, String>> it2 = topicResults.entrySet().iterator();
			while(it2.hasNext()){
				Map.Entry<String, String> entry2 = (Map.Entry<String, String>)it2.next();
				System.out.println("-->" + entry2.getKey() + "-" +entry2.getValue());
			}
		}
	}
}
