package uk.ac.shef.is.imageClef.qrel;

import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

/** Class is container of exactly one topic of a Qrel file.
 * @author Thomas Arni
 *
 */
public class TopicQrelsContainer {
	private String topicNr = "";
	//topicQrels<docNr, relevance>
	private HashMap<String, String> topicQrels = new HashMap<String, String>();
	
	public TopicQrelsContainer(String topicNr){
		this.topicNr = topicNr;
	}
	
	/** Returns topic number
	 * @return topic number
	 */
	public String getTopicNr() {
		return topicNr;
	}
	
	/** Add a relevance judgment to the container
	 * @param docNr document number to be added
	 * @param relevance relevance of the document to be added (0 = non-relevant / 1 + relevant)
	 */
	public void addJudgement(String docNr, String relevance){
		topicQrels.put(docNr, relevance);
	}
	
	/** Return true if the document is relevant
	 * @param docNr Requested document number
	 * @return true if document is relevant
	 */
	public boolean isRelevant(String docNr){
		return topicQrels.containsKey(docNr);
	}
	
	/** Return the assessment of the topic
	 * topicQrels<docNr,relevance>
	 * @return topic assessments
	 */
	public HashMap<String, String> getTopicQrels() {
		return topicQrels;
	}
	
	/** Returns the number of relevant images of the topic
	 * @return number of relevant images
	 */
	public int getNumberOfRelevantImages(){
		int numberOfRelImages = 0;
		Iterator<Map.Entry<String, String>> it = topicQrels.entrySet().iterator();
		while(it.hasNext()){
			Map.Entry<String, String> entry = (Map.Entry<String, String>)it.next();
			String rel = entry.getValue();
			//check if every docNr in the qrel-file is also in the cluster assessment file
			if(rel.equals("1")){
				numberOfRelImages++;
			}
		}
		return numberOfRelImages;		
	}
}
